@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2014-2024 ircd-hybrid development team
+ *  Copyright (c) 2014-2025 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -118,9 +118,7 @@ pseudo_register(const char *name, const char *nick, const char *server, const ch
   pseudo->nick = io_strdup(nick);
   pseudo->server = io_strdup(server);
   pseudo->command = io_strdup(command);
-  if (!EmptyString(prepend))
-    pseudo->prepend = io_strdup(prepend);
-
+  pseudo->prepend = !EmptyString(prepend) ? io_strdup(prepend) : NULL;
   pseudo->command_struct = (struct Command) {
     .name = pseudo->command,
     .extra = pseudo,
